#
# spec file for package pcsc-lite (Version 1.2.9_beta9)
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           pcsc-lite
BuildRequires:  libusb pkgconfig readline-devel resmgr
%define ifddir		%{_prefix}/%{_lib}/readers
%define auxbindir	%{_prefix}/%{_lib}/pcsc-lite
%define pcsc_version	1.2.9-beta9
Version:        1.2.9_beta9
Release:        17.19.1
PreReq:         %{insserv_prereq} %{fillup_prereq}
AutoReqProv:    on
Group:          System/Libraries
License:        BSD 3-Clause
Url:            http://www.linuxnet.com/
Summary:        The MUSCLE project SmartCards library
Source0:        %{name}-%{pcsc_version}.tar.bz2
Source1:        pcscd.init
Source2:        README.SUSE
Source3:        pre_checkin.sh
Patch:          pcsc-lite-CVE-2010-0407.patch
Patch1:         pcsc-lite-CVE-2010-4531.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%package devel
License:        BSD 3-Clause
Group:          System/Libraries
Summary:        Development package for the MUSCLE project SmartCards library
Requires:       pcsc-lite glibc-devel
Suggests:       pkgconfig

%description
The purpose of PCSC Lite is to provide a Windows(R) SCard interface in
a very small form factor for communicating with smartcards and readers.
PCSC Lite can be compiled directly for a desired reader driver or can
be used to dynamically allocate/deallocate reader drivers at runtime
(the default behavior).

PCSC Lite uses the same winscard api as used in Windows(R).

Security aware people should read the SECURITY file for possible
vulnerabilities to pcsclite, how you can fix them, and how some will be
fixed.

For information on how to install drivers please read the DRIVERS file.

Memory cards will be supported through the MCT specifications, which is
an APDU like manner sent normally through the SCardTransmit() function.
 This functionality is done in the driver.



Authors:
--------
    David Corcoran <corcoran@linuxnet.com>

%description devel
This package contains the development files for pcsc-lite. It allows to
compile plugins for the pcsc-lite package.



Authors:
--------
    David Corcoran <corcoran@linuxnet.com>

%prep
%setup -q -n %{name}-%{pcsc_version}
%patch -p1
%patch1 -p1

%build
%{suse_update_config -f}
aclocal --force -I m4
libtoolize --force
autoconf --force
autoheader --force
automake -afc
CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -Wall" \
	./configure \
	--prefix=%{_prefix}	\
	--bindir=%{_bindir}	\
	--sbindir=%{_sbindir}	\
	--libdir=%{_libdir}	\
	--mandir=%{_mandir}	\
	--includedir=%{_includedir} \
	--enable-usb		\
	--enable-utils		\
	--enable-syslog		\
	--enable-daemon		\
	--enable-usbdropdir=%{ifddir} \
	--sysconfdir=%{_sysconfdir}
make 
make -C src testpcsc
make -C src/utils

%install
export DESTDIR=$RPM_BUILD_ROOT
export PKG_CONFIG_PATH=$PWD/src
install -d 	$DESTDIR/etc/init.d \
	   	$DESTDIR%ifddir \
	   	$DESTDIR%auxbindir \
	   	$DESTDIR%{_prefix}/bin/ \
                $DESTDIR%{_libdir} \
		$DESTDIR%{_libdir}/readers/
make install DESTDIR=$DESTDIR
touch $DESTDIR%{_sysconfdir}/reader.conf
install -m 755 src/.libs/testpcsc $DESTDIR/%auxbindir
install -m 755 %{S:1} $DESTDIR/etc/init.d/pcscd
ln -sf ../../etc/init.d/pcscd $DESTDIR%_prefix/sbin/rcpcscd
# set libraries as executable - prevent ldd from complaining
chmod +x $DESTDIR%{_libdir}/*.so*
# cleanup : remove unpackaged files
# first two are in auxbindir
rm -f $RPM_BUILD_ROOT/usr/doc/*
rm -f $RPM_BUILD_ROOT/%{_mandir}/man3/*

%clean
rm -rf $RPM_BUILD_ROOT

%pre
# save old reader.conf in update case
if [ "$1" = "2" ]; then
	if [ ! -d /etc/reader.conf.d ]; then # update from old version
		mkdir -p /etc/reader.conf.d
		cp /etc/reader.conf /etc/reader.conf.d/old-reader.conf
	fi
fi

%post
%{run_ldconfig}
%{fillup_and_insserv pcscd}

%postun
%{run_ldconfig}
%{insserv_cleanup}

%files
%defattr(444,root,root,755)
%doc ChangeLog AUTHORS NEWS README SECURITY doc/README.DAEMON
%doc doc/*.pdf DRIVERS
%attr(555,root,root) /etc/init.d/pcscd
%attr(555,root,root) %{_prefix}/sbin/rcpcscd
%ghost %verify (not md5 mtime size) %{_sysconfdir}/reader.conf
%attr(755,root,root) %dir %{_sysconfdir}/reader.conf.d
%attr(644,root,root) %config %{_sysconfdir}/reader.conf.d/reader.conf
%attr(555,root,root) %{_libdir}/lib*.so.*
# .so must be in the main package
%{_libdir}/lib*.so
%attr(555,root,root) %{_prefix}/sbin/pcscd
%attr(444,root,root) %{_mandir}/man?/*
%attr(755,root,root) %dir %auxbindir
%attr(555,root,root) %auxbindir/testpcsc
%attr(555,root,root) %{_sbindir}/installifd
%attr(555,root,root) %{_sbindir}/update-reader.conf
%attr(555,root,root) %{_bindir}/formaticc
%attr(555,root,root) %{_sbindir}/bundleTool
%attr(755,root,root) %dir %ifddir

%files devel
%defattr(644,root,root,755)
%{_includedir}/*
%{_libdir}/lib*.*a
%{_libdir}/pkgconfig/*

%changelog
* Tue Jan  4 2011 sbrabec@suse.cz
- Fixed stack overflow in ATR attribute decoding (bnc#661000,
  CVE-2010-4531).
* Fri Jul  2 2010 sbrabec@suse.cz
- Fix of broken checks in the previous fix (bnc#609317#c13).
* Fri May 28 2010 sbrabec@suse.cz
- Local root exploit vulnerability fix (bnc#609317, CVE-2010-0407).
* Wed Jan 17 2007 sbrabec@suse.cz
- pcsclite.so moved to the main package (#235773).
* Thu Apr  6 2006 mjancar@suse.cz
- remove powermgt_macosx.c from the package (#161324)
* Mon Mar 13 2006 mjancar@suse.cz
- mount /proc/bus/usb in initscript anyway (#146979)
* Tue Feb  7 2006 mjancar@suse.cz
- start after kbd instead of mounting usbfs ourselfs (#146979)
* Mon Feb  6 2006 mjancar@suse.cz
- mount /proc/bus/usb in initscript (#146979)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan  3 2006 mjancar@suse.cz
- move drivers to separate source packages
- branch devel subpackage
* Mon Jan  2 2006 stark@suse.de
- removed obsolete hotplug stuff for cyberjack
- Updated pcsc-lite to version 1.2.9-beta9
- Updated CCID driver to 0.9.4
- Updated GemPC driver to 1.0.0
- package pkgconfig files to be able to build drivers outside
  the package
* Tue Dec 20 2005 ro@suse.de
- removed unpackaged man-page symlinks
* Tue Nov 29 2005 ro@suse.de
- remove keeper from nfb (unused)
* Mon Oct 10 2005 stark@suse.de
- Updated towitoko driver to 2.0.7 and install USB bundle
* Wed Sep 21 2005 stark@suse.de
- Repackaged CCID as bundle for USB usage (#116497)
* Tue Sep 20 2005 stark@suse.de
- handle old reader.conf in upgrade case
- compile with -fno-strict-aliasing
- fixed missing return in ctapi-cyberjack
* Sat Sep 17 2005 stark@suse.de
- Updated pcsc-lite to version 1.2.9beta8 (#116497)
  * use /etc/reader.conf.d/
  * adapted init script to create /etc/reader.conf
- Updated cyberjack driver to version 2.0.9
  * use rpath for cyberjack tools
- Updated ccid driver to version 0.9.3 (#116497)
- Use RPM_OPT_FLAGS everywhere
- Fixed serious compiler warnings
* Mon Sep  5 2005 skh@suse.de
- fix off-by-one error in hotplug_libusb.c [#112964]
* Mon Aug 29 2005 skh@suse.de
- Remove unnecessary files from pcsc-acr38 again [#112927]
* Mon Aug 29 2005 skh@suse.de
- package ACR38 driver in correct bundle format [#112927]
- remove orphaned /var/run/pcscd.pub when necessary [#112928]
- update ACR38u driver to version 100705 to fix crash when reader
  is plugged in [#112964]
* Tue Aug 16 2005 skh@suse.de
- Updated ACR38u driver to version 100703
* Tue Jul 26 2005 okir@suse.de
- Added ACR38u driver
* Tue Jul 26 2005 okir@suse.de
- Updated description in init script (#79287)
* Thu Jun 16 2005 meissner@suse.de
- use RPM_OPT_FLAGS in 1 more driver
- added includes to avoid implict declaration of memcpy and similar.
* Mon Apr 18 2005 ro@suse.de
- make it build with gcc-4
* Thu Mar 17 2005 okir@suse.de
- Disable support for extended-apdus, it eats 32MB of memory (#73629)
* Thu Mar 10 2005 okir@suse.de
- Fix default search location for USB bundles
* Fri Jan 21 2005 okir@suse.de
- Updated to latest upstream version
- Updated several drivers
- Added CCID driver
- Provide a more informative readers.conf file (#42620)
* Thu Jan 20 2005 ro@suse.de
- drop subpackage gpr400
* Wed Apr 28 2004 ro@suse.de
- compile formaticc with no-strict-aliasing
- fix unused return type in musclecard.c
* Wed Mar 31 2004 okir@suse.de
- Properly install testpcsc, formaticc (#37625)
- Build towitoko driver with --enable-win32-com
* Thu Mar 18 2004 okir@suse.de
- cyberjack apps installed in /bin should be executable (#36409)
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Tue Aug  5 2003 mge@suse.de
- merge ctapi-cyberjack into pcsc-lite: two additional
  packages are created: ctapi-cyberjack and pcsc-cyberjack
* Thu Jun 26 2003 ro@suse.de
- remove unpackaged files from buildroot
- added directories to filelist
* Fri Nov 29 2002 okir@suse.de
- added -fPIC when building eToken driver
* Fri Nov 29 2002 okir@suse.de
- Updated to latest upstream version
- Included driver for Aladdin eToken PRO
- More GNU auto#*@! headaches
- Various minor fixes
* Wed Aug 28 2002 okir@suse.de
- Moved shared objects to /usr/lib64 on ppc64/s390x (#18421)
* Mon Aug  5 2002 olh@suse.de
- fix initscript, Should-start: setserial hotplug
* Fri Aug  2 2002 okir@suse.de
- added PreReq for insserv_and_fillup
* Wed Jul 31 2002 okir@suse.de
- fixed build problem on s390x (force aclocal.m4 regen)
* Wed Jun 26 2002 ro@suse.de
- use -fPIC when building a shared lib
* Wed Jun 12 2002 okir@suse.de
- fix for bug #15051 (hey, it's a palindrome bug:):
  missing %%doc DRIVERS file; misc silly binaries moved
  out of /usr/bin
* Tue Apr 30 2002 okir@suse.de
- Fixed build problem introduced by previous patch
* Tue Apr 30 2002 okir@suse.de
- updated to latest upstream version
- added drivers for these readers: Towitoko, Schlumberger Reflex 6x,
  Gemplus GPR 400, GemPlus GemPC 410/430
* Tue Apr  9 2002 ro@suse.de
- fixed for latest automake/autoconf
* Wed Feb 13 2002 stark@suse.de
- spec-file cleanup
- LSB compliant init-script
* Mon Jan 14 2002 ro@suse.de
- removed START_PCSCD
* Wed Nov 14 2001 ro@suse.de
- call aclocal
* Sun Aug 26 2001 mge@suse.de
- updated to 1.0.0Beta
- fixed /etc/init.d/pcscd status-handling (bug #9069)
* Thu Jun  7 2001 ro@suse.de
- fix broken Makefile.am
* Sun Apr 22 2001 mge@suse.de
- update to 0.9.1
* Wed Apr 18 2001 mge@suse.de
- created package
